help: Drop-in replacements for help and ? functions

helpR Documentation

Drop-in replacements for help and ? functions

Description

The ⁠?⁠ and help functions are drop-in replacements for those in the utils package. They automatically translate help to the language specified by the LANG or LANGUAGE environment variables, or by lang_use().

Usage

# help(topic, package = NULL, ...)

# ?e2
# e1?e2

Arguments

topic

A name or character string specifying the help topic.

package

A name or character string specifying the package in which to search for the help topic. If NULL, search all packages.

...

Additional arguments to pass to utils::help().

e1

First argument to pass along to ⁠utils::⁠?“.

e2

Second argument to pass along to ⁠utils::⁠?“.


lang documentation built on June 5, 2026, 5:08 p.m.