lang-package: lang: Translates R Help Documentation using Large Language...

lang-packageR Documentation

lang: Translates R Help Documentation using Large Language Models

Description

logo

Translates R help documentation on the fly by using a Large Language model of your choice. If you are using 'RStudio' or 'Positron' the translated help will appear in the help pane.

Author(s)

Maintainer: Edgar Ruiz edgar@posit.co

Authors:

Other contributors:

  • Posit Software, PBC (ROR) [copyright holder, funder]

See Also

Useful links:


lang documentation built on June 5, 2026, 5:08 p.m.