| help | R Documentation |
The ? and help functions are drop-in replacements for those in the
utils package. They automatically translate help to the language specified
by the LANG or LANGUAGE environment variables, or by lang_use().
# help(topic, package = NULL, ...)
# ?e2
# e1?e2
topic |
A name or character string specifying the help topic. |
package |
A name or character string specifying the package in which to search for the help topic. If NULL, search all packages. |
... |
Additional arguments to pass to |
e1 |
First argument to pass along to |
e2 |
Second argument to pass along to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.