| lang-package | R Documentation |
Translates R help documentation on the fly by using a Large Language model of your choice. If you are using 'RStudio' or 'Positron' the translated help will appear in the help pane.
Maintainer: Edgar Ruiz edgar@posit.co
Authors:
Edgar Ruiz edgar@posit.co
Other contributors:
Posit Software, PBC (ROR) [copyright holder, funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.